summaryrefslogtreecommitdiffstats
path: root/kmobile/devices/gnokii/gnokii_mobile.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmobile/devices/gnokii/gnokii_mobile.h')
-rw-r--r--kmobile/devices/gnokii/gnokii_mobile.h19
1 files changed, 10 insertions, 9 deletions
diff --git a/kmobile/devices/gnokii/gnokii_mobile.h b/kmobile/devices/gnokii/gnokii_mobile.h
index 6be2196a..9562c222 100644
--- a/kmobile/devices/gnokii/gnokii_mobile.h
+++ b/kmobile/devices/gnokii/gnokii_mobile.h
@@ -17,8 +17,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#ifndef LIBKMOBILE_GNOKII_H
@@ -30,25 +30,26 @@
class KMobileGnokii : public KMobileDevice
{
Q_OBJECT
+ TQ_OBJECT
public:
KMobileGnokii( TQObject *obj=0, const char *name=0, const TQStringList &args=TQStringList() );
~KMobileGnokii();
// createObject needs to be reimplemented by every KMobileDevice driver
- TQObject *createObject( TQObject *parent=0, const char *name=0,
- const char *classname="TQObject", const TQStringList &args=TQStringList() );
+ TQObject *createObject( TQObject *tqparent=0, const char *name=0,
+ const char *classname=TQOBJECT_OBJECT_NAME_STRING, const TQStringList &args=TQStringList() );
// connect, disconnect and current status
- bool connectDevice(TQWidget *parent);
- bool disconnectDevice(TQWidget *parent);
+ bool connectDevice(TQWidget *tqparent);
+ bool disconnectDevice(TQWidget *tqparent);
- // provide a device-specific configure dialog
- bool configDialog(TQWidget *parent);
+ // provide a tqdevice-specific configure dialog
+ bool configDialog(TQWidget *tqparent);
// filename and path to gnokii-icon
TQString iconFileName() const;
- TQString deviceUniqueID();
+ TQString tqdeviceUniqueID();
/*
* Addressbook / Phonebook support